@@ -901,10 +901,12 @@ class AdsAPI(object):
             args['adgroup_status'] = adgroup_status
         return self.make_request(path, 'POST', args, batch=batch)
 
+    # Deprecated: this method will be update at Oct 1st 2014, breaking change on Facebook..
     def create_custom_audience(self, account_id, name, subtype=None,
                                description=None, rule=None, opt_out_link=None,
                                retention_days=30, batch=False):
         """Create a custom audience for the given account."""
+        logger.warn("This method is deprecated. This method will be changed in order to support new rule of facebook ads api.")
         path = "act_%s/customaudiences" % account_id
         args = {
             'name': name,
@@ -936,16 +938,31 @@ class AdsAPI(object):
         }
         return self.make_request(path, 'POST', args, batch)
 
+    def create_custom_audience_pixel(self, account_id, batch=False):
+        """Create a custom audience pixel for the given account.
+        This method only needed once per ad account."""
+        path = "act_%s/adspixels" % account_id
+        return self.make_request(path, 'POST', batch=batch)
+
     def create_custom_audience_from_website(
             self, account_id, name, domain, description=None,
-            retention_days=30, batch=False):
+            retention_days=30, prefill=True, batch=False):
         """Create a custom audience from website for the given account."""
+        path = "act_%s/customaudiences" % account_id
+        args = {
+            'name': name,
+            'subtype': "WEBSITE"
+        }
         rule = {'url': {
             'i_contains': domain,
         }}
-        return self.create_custom_audience(
-            account_id, name, "WEBSITE", description=description, rule=rule,
-            retention_days=retention_days, batch=batch)
+        if rule:
+            args['rule'] = json.dumps(rule)
+        if retention_days:
+            args['retention_days'] = retention_days
+        if prefill:
+            args['prefill'] = prefill
+        return self.make_request(path, 'POST', args, batch=batch)
 
     def create_lookalike_audience(self, account_id, name, audience_id,
                                   lookalike_spec, batch=False):
